# © 2021 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import models


class ScopBordereau(models.Model):
    _name = "scop.bordereau"
    _inherit = ["scop.bordereau", "cgscop.alfresco"]

    # ------------------------------------------------------
    # Commmon function
    # ------------------------------------------------------
    def upload_contribution_file(self):
        try:
            name = "Appel de Cotisation " + str(self.year) + " - " + self.name + ".pdf"

            report_bdx = self.env.ref(
                "cgscop_cotisation_cg.cgscop_bordereau_report"
            )._render_qweb_pdf(self.id)[0]
            node_ref = self.push_alfresco_file(
                file=report_bdx,
                name=name,
                folder=self.partner_id.partner_cmis_folder,
                metadata={
                    "cm:title": name,
                    "cmis:objectTypeId": "D:crm:document",
                    "cmis:secondaryObjectTypeIds": [
                        "P:crm:organisme",
                        "P:cm:titled",
                        "P:ut:flags",
                    ],
                    "crm:type": "APC",
                    "crm:contexte": "COT",
                    "crm:annee": str(self.year),
                    "ut:doNotRename": "true",
                },
            )
        except Exception as e:
            raise e
        return node_ref

    # ------------------------------------------------------
    # Override parent
    # ------------------------------------------------------
    def validate_bordereau(self, message_id=False):
        try:
            bdx = super(ScopBordereau, self).validate_bordereau(message_id)
            self.upload_contribution_file()
        except Exception as e:
            raise e
        return bdx

    # ------------------------------------------------------
    # To Delete after upload
    # ------------------------------------------------------
    def load_contribution(self, states=None, year=None):
        """
        Fonction pour charger les pdf des bordereaux depuis un CRON
        ou une action serveur
        """
        if not states:
            states = []
        domain = []
        params = ""
        if states:
            domain.append(("state", "in", states))
            params += " | " + ",".join(states)
        if year:
            domain.append(("year", "=", year))
            params += " | " + str(year)
        bdx_ids = self.search(domain)

        # batch queue creation
        batch_name = "Chargement PDF cotisations " + params
        batch = self.env["queue.job.batch"].get_new_batch(batch_name)
        for bdx in bdx_ids:
            bdx.with_context(job_batch=batch).with_delay().upload_contribution_file()
        batch.enqueue()
